@@ -1,4 +1,4 @@
-# Copyright (c) 2023 Technica Engineering GmbH. All rights reserved.
+# Copyright (c) 2024 Technica Engineering GmbH. All rights reserved.
 
 import clr
 import System
@@ -69,6 +69,7 @@ from PrimaITestCaseLibrary.MessageManagment import ISomeIPHeader as ISomeIPHeade
 from PrimaITestCaseLibrary import MessageType as MessageType
 from PrimaITestCaseLibrary import ReturnCode as ReturnCode
 from PrimaITestCaseLibrary.MessageManagment import ISomeIpTpHeader as ISomeIpTpHeader
+from PrimaITestCaseLibrary.MessageManagment import AutoCalculate as AutoCalculate
 from PrimaITestCaseLibrary.RestBusSimulation.RestBusSimulationSOMEIP import SendingSomeIPSDEventArgs as SendingSomeIPSDEventArgs
 from PrimaITestCaseLibrary.MessageManagment import IMessageSomeIPSD as MessageSomeIPSD
 from PrimaITestCaseLibrary import IEntry as Entry
@@ -82,6 +83,79 @@ from PrimaITestCaseLibrary.MessageManagment import ISDHeader as ISDHeader
 from PrimaITestCaseLibrary.RestBusSimulation.RestBusSimulationSOMEIP import ReceivingEventArgs as ReceivingEventArgs
 from PrimaITestCaseLibrary.RestBusSimulation.RestBusSimulationSOMEIP import ValueChangedArgs as ValueChangedArgs
 from PrimaITestCaseLibrary.RestBusSimulation.RestBusSimulationSOMEIP import MethodCalledArgs as MethodCalledArgs
+from PrimaITestCaseLibrary.DataBases import IFibexEthernet as DatabaseEthernet
+from Technica.Databases.Ethernet import IConsumedEventGroup as IConsumedEventGroup
+from Technica.Databases.Ethernet import IServiceInterface as IServiceInterface
+from Technica.Databases.Ethernet import Package as Package
+from Technica.Databases.Ethernet import Event as Event
+from Technica.Databases.Can import IE2EInformation as IE2EInformation
+from Technica.Databases.Can import ISignalInstance as ISignalInstance
+from Technica.Databases.Ethernet import CALLSEMANTIC as CALLSEMANTIC
+from Technica.Databases.Ethernet import IManufacturerMethodExtension as IManufacturerMethodExtension
+from Technica.Databases.Ethernet import SomeIpTP as SomeIpTP
+from Technica.Databases.Ethernet import Method as Method
+from Technica.Databases.Ethernet import IEventGroup as IEventGroup
+from Technica.Databases.Ethernet import Field as Field
+from Technica.Databases.Ethernet import IApplicationEndpoint as IApplicationEndpoint
+from Technica.Databases.Ethernet import IProvidedService as IProvidedService
+from Technica.Databases.Ethernet import IEventHandler as IEventHandler
+from Technica.Databases.Ethernet import INetwork as INetwork
+from Technica.Databases.Ethernet import INetworkEndpointAddress as INetworkEndpointAddress
+from Technica.Databases.Ethernet import IPv4AddresSource as IPv4AddresSource
+from Technica.Databases.Ethernet import IConsumedService as IConsumedService
+from Technica.Databases.Can import IConnector as IConnector
+from Technica.Databases.Common import IEcu as IEcu
+from Technica.Databases.Common import TpAddress as TpAddress
+from Technica.Databases.Can import IChannel as IChannel
+from Technica.Databases.Can import IPduTriggering as IPduTriggering
+from Technica.Databases.Can import IPduType as IPduType
+from Technica.Databases.Can import FrameType as FrameType
+from Technica.Databases.CommonClasses import ISignalGroupInstance as ISignalGroupInstance
+from Technica.Databases.Common import ISignalGroup as ISignalGroup
+from Technica.Databases.Can import IMultiplexedPart as IMultiplexedPart
+from Technica.Databases.Can import ISwitchedPduInstance as ISwitchedPduInstance
+from Technica.Databases.Can import ISegmentPosition as ISegmentPosition
+from Technica.Databases.Common import ISecOCConfiguration as ISecOCConfiguration
+from Technica.Databases.Can import IContainedProps as IContainedProps
+from Technica.Databases.Can import HeaderType as HeaderType
+from Technica.Databases.Common import ICluster as ICluster
+from Technica.Databases.Ethernet import IMacMulticastGroup as IMacMulticastGroup
+from Technica.Databases.Ethernet import CouplingPort as CouplingPort
+from Technica.Databases.Ethernet import VlanMembership as VlanMembership
+from Technica.Databases.Ethernet import IChannelEthernet as IChannelEthernet
+from Technica.Databases.Can import IFrameTriggering as IFrameTriggering
+from Technica.Databases.Can import IFrame as IFrame
+from Technica.Databases.Can import IPduInstance as IPduInstance
+from Technica.Databases.Can import ISignalTriggering as ISignalTriggering
+from Technica.Databases.Ethernet import IController as IController
+from Technica.Databases.Can import IPduTiming as IPduTiming
+from Technica.Databases.Can import ICyclicTiming as ICyclicTiming
+from Technica.Databases.Can import IEventTiming as IEventTiming
+from Technica.Databases.Can import ISignalTrigger as ISignalTrigger
+from Technica.Databases.Can import ISignalInstanceRef as ISignalInstanceRef
+from Technica.Databases.Can import IEcuPort as IEcuPort
+from Technica.Databases.Ethernet import IECUEthernet as IECUEthernet
+from Technica.Databases.Ethernet import CouplingElement as CouplingElement
+from PrimaITestCaseLibrary.RestBusSimulation.RestBusSimulationSignals import IEcuSignalsNode as IEcuSignalsNode
+from PrimaITestCaseLibrary.Utilities import SignalValue as SignalValue
+from PrimaITestCaseLibrary.RestBusSimulation.RestBusSimulationBase import ValueChangedArgsMsg as ValueChangedArgsMsg
+from PrimaITestCaseLibrary.RestBusSimulation import IEcuMessageBasedNode as IEcuMessageBasedNode
+from PrimaITestCaseLibrary.DataBases import ISignalDatabase as ISignalDatabase
+from Technica.Databases.Can import ISignalEcu as ISignalEcu
+from Technica.Databases.Can import IFrameInstance as IFrameInstance
+from Technica.Databases.Ethernet import INetworkConfiguration as INetworkConfiguration
+from Technica.Databases.Lin import IProduct as IProduct
+from Technica.Databases.Lin import ScheduleTable as ScheduleTable
+from Technica.Databases.Lin import ScheduleCommand as ScheduleCommand
+from Technica.Databases.Common import ITpConfig as ITpConfig
+from Technica.Databases.Common import ICanTpConnection as ICanTpConnection
+from Technica.Databases.Common import AddressingFormat as AddressingFormat
+from Technica.Databases.Common import TargetType as TargetType
+from Technica.Databases.Common import ITpNode as ITpNode
+from Technica.Databases.Common import ILinTpConnection as ILinTpConnection
+from Technica.Databases.Common import IDoIpTpConnection as IDoIpTpConnection
+from Technica.Databases.Common import IPduPool as IPduPool
+from Technica.Databases.Common import IFrTpConnection as IFrTpConnection
 from PrimaITestCaseLibrary.NetWorksConfig import IChannelAdapter as IChannelAdapter
 from PrimaITestCaseLibrary.TestCaseLibrary import IAdapter as Adapter
 from PrimaTestCaseLibrary.Utils import BusData as BusData
@@ -94,46 +168,11 @@ from PrimaTestCaseLibrary.Utils import IP as IP
 from PrimaITestCaseLibrary.TestCaseLibrary import ISeriesBuilder as SeriesBuilder
 from PrimaITestCaseLibrary.TestCaseLibrary import ISeries as Series
 from PrimaITestCaseLibrary.TestCaseLibrary import Node as Node
-from PrimaITestCaseLibrary.RestBusSimulation.RestBusSimulationCAN import IEcuCANNode as EcuNodeCAN
-from PrimaITestCaseLibrary.Utilities import SignalValue as SignalValue
-from PrimaITestCaseLibrary.RestBusSimulation.RestBusSimulationBase import ValueChangedArgsMsg as ValueChangedArgsMsg
-from PrimaITestCaseLibrary.RestBusSimulation import IEcuMessageBasedNode as IEcuMessageBasedNode
+from PrimaITestCaseLibrary.RestBusSimulation.RestBusSimulationPdu import IEcuPduNode as EcuNodePDU
+from PrimaITestCaseLibrary.RestBusSimulation.RestBusSimulationCAN import IEcuCanNode as EcuNodeCAN
 from PrimaITestCaseLibrary.NetWorksConfig import IBrspyCanChannelAdapter as ChannelBrspyCAN
 from PrimaITestCaseLibrary.MessageManagment import IMessageCAN as MessageCAN
 from PrimaITestCaseLibrary.MessageManagment import ICANHeader as ICANHeader
-from Technica.Databases.Can import IFrameInstance as IFrameInstance
-from Technica.Databases.Can import IE2EInformation as IE2EInformation
-from Technica.Databases.Can import ISignalInstance as ISignalInstance
-from Technica.Databases.Can import IPduTiming as IPduTiming
-from Technica.Databases.Can import ICyclicTiming as ICyclicTiming
-from Technica.Databases.Can import IEventTiming as IEventTiming
-from Technica.Databases.Can import ISignalTrigger as ISignalTrigger
-from Technica.Databases.Can import ISignalInstanceRef as ISignalInstanceRef
-from Technica.Databases.Ethernet import INetworkConfiguration as INetworkConfiguration
-from Technica.Databases.Ethernet import INetwork as INetwork
-from Technica.Databases.Ethernet import INetworkEndpointAddress as INetworkEndpointAddress
-from Technica.Databases.Ethernet import IPv4AddresSource as IPv4AddresSource
-from Technica.Databases.Can import IFrameTriggering as IFrameTriggering
-from Technica.Databases.Can import IFrame as IFrame
-from Technica.Databases.Can import IPduInstance as IPduInstance
-from Technica.Databases.Can import IPduType as IPduType
-from Technica.Databases.Can import FrameType as FrameType
-from Technica.Databases.CommonClasses import ISignalGroupInstance as ISignalGroupInstance
-from Technica.Databases.Common import ISignalGroup as ISignalGroup
-from Technica.Databases.Can import IChannel as IChannel
-from Technica.Databases.Can import IPduTriggering as IPduTriggering
-from Technica.Databases.Common import ICluster as ICluster
-from Technica.Databases.Ethernet import IMacMulticastGroup as IMacMulticastGroup
-from Technica.Databases.Ethernet import CouplingPort as CouplingPort
-from Technica.Databases.Ethernet import VlanMembership as VlanMembership
-from Technica.Databases.Ethernet import IChannelEthernet as IChannelEthernet
-from Technica.Databases.Can import ISignalTriggering as ISignalTriggering
-from Technica.Databases.Ethernet import IController as IController
-from Technica.Databases.Can import IMultiplexedPart as IMultiplexedPart
-from Technica.Databases.Can import ISwitchedPduInstance as ISwitchedPduInstance
-from Technica.Databases.Can import ISegmentPosition as ISegmentPosition
-from Technica.Databases.Common import ISecOCConfiguration as ISecOCConfiguration
-from PrimaITestCaseLibrary.MessageManagment import AutoCalculate as AutoCalculate
 from PrimaITestCaseLibrary.NetWorksConfig import IRecordHandler as IRecordHandler
 from PrimaITestCaseLibrary.NetWorksConfig import IBrspyChannelAdapter as ChannelBrspy
 from PrimaITestCaseLibrary.NetWorksConfig import IBtsCanChannelAdapter as ChannelBtsCAN
@@ -159,42 +198,9 @@ from PrimaITestCaseLibrary.MessageManagment import IMessageFlexRayHeader as IMes
 from PrimaITestCaseLibrary.NetWorksConfig import IPlpLinChannelAdapter as ChannelPlpLin
 from PrimaITestCaseLibrary.NetWorksConfig import IPlpSerialChannelAdapter as ChannelPlpSerial
 from PrimaITestCaseLibrary.DataBases import ICanDatabase as DatabaseCAN
-from Technica.Databases.Can import ISignalEcu as ISignalEcu
-from Technica.Databases.Common import TpAddress as TpAddress
-from Technica.Databases.Common import ITpConfig as ITpConfig
-from Technica.Databases.Common import ICanTpConnection as ICanTpConnection
-from Technica.Databases.Common import AddressingFormat as AddressingFormat
-from Technica.Databases.Common import ITpNode as ITpNode
-from Technica.Databases.Can import IConnector as IConnector
-from Technica.Databases.Common import IEcu as IEcu
-from Technica.Databases.Can import IEcuPort as IEcuPort
-from Technica.Databases.Ethernet import IApplicationEndpoint as IApplicationEndpoint
-from Technica.Databases.Ethernet import IProvidedService as IProvidedService
-from Technica.Databases.Ethernet import IServiceInterface as IServiceInterface
-from Technica.Databases.Ethernet import Package as Package
-from Technica.Databases.Ethernet import Event as Event
-from Technica.Databases.Ethernet import CALLSEMANTIC as CALLSEMANTIC
-from Technica.Databases.Ethernet import IManufacturerMethodExtension as IManufacturerMethodExtension
-from Technica.Databases.Ethernet import Method as Method
-from Technica.Databases.Ethernet import IEventGroup as IEventGroup
-from Technica.Databases.Ethernet import Field as Field
-from Technica.Databases.Ethernet import IEventHandler as IEventHandler
-from Technica.Databases.Ethernet import IConsumedEventGroup as IConsumedEventGroup
-from Technica.Databases.Ethernet import IConsumedService as IConsumedService
-from Technica.Databases.Common import TargetType as TargetType
-from Technica.Databases.Common import IPduPool as IPduPool
-from Technica.Databases.Common import IFrTpConnection as IFrTpConnection
 from PrimaITestCaseLibrary.DataBases import IEdiabasDatabase as DatabaseEdiabas
-from PrimaITestCaseLibrary.DataBases import IFibexEthernet as DatabaseEthernet
-from Technica.Databases.Ethernet import IECUEthernet as IECUEthernet
-from Technica.Databases.Ethernet import CouplingElement as CouplingElement
 from PrimaITestCaseLibrary.DataBases import ILinDatabase as DatabaseLIN
-from Technica.Databases.Lin import ILinEcu as ILinEcu
-from Technica.Databases.Lin import IProduct as IProduct
-from Technica.Databases.Lin import ScheduleTable as ScheduleTable
-from Technica.Databases.Lin import ScheduleCommand as ScheduleCommand
 from PrimaITestCaseLibrary.DataBases import IPduDatabase as DatabasePDU
-from Technica.Databases.Pdu import PduEcu as PduEcu
 from PrimaITestCaseLibrary.OutputView import IOutputViewer as IOutputViewer
 from PrimaITestCaseLibrary.OutputView import OutputStringType as OutputStringType
 from PrimaITestCaseLibrary.Utilities import IAttribute as Variable
@@ -231,6 +237,8 @@ from PrimaITestCaseLibrary.MessageManagment import IMessageTCP as MessageTCP
 from PrimaITestCaseLibrary.MessageManagment import IMessageIEEE1722 as MessageIEEE1722
 from PrimaITestCaseLibrary.MessageManagment import IMessageICMP as MessageICMPv4
 from PrimaITestCaseLibrary.MessageManagment import ICMPv4TypeCodes1 as ICMPv4TypeCodes1
+from PrimaITestCaseLibrary.MessageManagment import IMessageICMPv6 as MessageICMPv6
+from PrimaITestCaseLibrary.MessageManagment import ICMPv6_TYPE as ICMPv6_TYPE
 from PrimaITestCaseLibrary import IMessageDHCP as MessageDHCP
 from PrimaITestCaseLibrary import mode as mode
 from PrimaITestCaseLibrary.MessageManagment import IipMessage as MessageIpv4
@@ -247,8 +255,6 @@ from PrimaITestCaseLibrary.MessageManagment import TlsCipherSuite as TlsCipherSu
 from PrimaITestCaseLibrary.MessageManagment import ITlsAlert as ITlsAlert
 from PrimaITestCaseLibrary.MessageManagment import AlertLevels as AlertLevels
 from PrimaITestCaseLibrary.MessageManagment import AlertDescription as AlertDescription
-from PrimaITestCaseLibrary.MessageManagment import IMessageICMPv6 as MessageICMPv6
-from PrimaITestCaseLibrary.MessageManagment import ICMPv6_TYPE as ICMPv6_TYPE
 from PrimaITestCaseLibrary.MessageManagment import IMessageSRP as MessageSRP
 from PrimaITestCaseLibrary.MessageManagment import ISRPSubMessage as ISRPSubMessage
 from PrimaITestCaseLibrary.MessageManagment import ISRPVectorAttribute as ISRPVectorAttribute
