@@ -1,3 +1,4 @@
+import atexit
 import os
 import sys
 # set the python executable environment variable since some scripts might need it
@@ -5,7 +6,7 @@ os.environ["PYTHON_EXECUTABLE"] = sys.executable
 current_dir = os.path.dirname(os.path.abspath(__file__))
 # we need to set the runtime of pythonnet to use netcoreapp instead of netframework
 from clr_loader import get_coreclr
-from pythonnet import set_runtime
+from pythonnet import set_runtime, unload
 # we get the core runtime configuration from the runtimeconfig file
 rt = get_coreclr(runtime_config=os.path.join(current_dir, 'runtimeconfig.json'))
 
@@ -25,7 +26,10 @@ import logging
 default_handlers = logging.root.handlers
 logging.basicConfig(level=logging.NOTSET, format="%(message)s", datefmt="[%X]", handlers=default_handlers)
 default_logger = logging.getLogger("andi.default")
-          
+
+# Workaround until https://github.com/pythonnet/pythonnet/issues/1977 gets fixed
+atexit.unregister(unload)
+
 class AndiApi(dict):
     def __init__(self, *args, **kwargs):
         super(AndiApi, self).__init__(*args, **kwargs)
@@ -117,9 +121,11 @@ def enable_rich_logging():
     rich_handler = rich.logging.RichHandler()
     logger = logging.getLogger('andi')
     logger.addHandler(rich_handler)
+   
 
 def disable_rich_logging():
     """Disable rich-based logging"""
     global rich_handler
     logger = logging.getLogger('andi')
     logger.removeHandler(rich_handler)
+    
